@@ -8,7 +8,7 @@ use crate::rules::non_critical_lints::{
     no_console::NoConsoleConfig, no_empty_function::NoEmptyFunctionConfig,
     no_restricted_syntax::NoRestrictedSyntaxConfig, no_use_before_define::NoUseBeforeDefineConfig,
     prefer_regex_literals::PreferRegexLiteralsConfig, quotes::QuotesConfig, radix::RadixConfig,
-    valid_typeof::ValidTypeofConfig, yoda::YodaConfig,
+    use_is_nan::UseIsNanConfig, valid_typeof::ValidTypeofConfig, yoda::YodaConfig,
 };
 
 #[derive(Debug, Clone, Copy, Serialize, Deserialize)]
@@ -143,6 +143,10 @@ pub struct LintConfig {
     #[serde(default, alias = "noNewSymbol")]
     pub no_new_symbol: RuleConfig<()>,
 
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "useIsNan")]
+    pub use_isnan: RuleConfig<UseIsNanConfig>,
+
     #[cfg(feature = "non_critical_lints")]
     #[serde(default, alias = "validTypeof")]
     pub valid_typeof: RuleConfig<ValidTypeofConfig>,
